@@ -12,6 +12,10 @@ class KerberosClientSocketSelector:
             return KerberosClientSocket(target)
         else:
             if target.proxy is not None:
-                return AIOKerberosClientSocksSocket(target)
+                if target.proxy.type == 'WSNET':
+                    from minikerberos.network.aioclientwsnetsocket import AIOKerberosClientWSNETSocket
+                    return AIOKerberosClientWSNETSocket(target)
+                else:
+                    return AIOKerberosClientSocksSocket(target)
             else:
                 return AIOKerberosClientSocket(target)
\ No newline at end of file
